==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebRadioDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRadioChangeEventArgsDescriptionMetadata } from "./WebRadioChangeEventArgsDescriptionMetadata";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
import { WebRadioDescription } from "./WebRadioDescription";
/**
 * @hidden
 */
var WebRadioDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebRadioDescriptionMetadata, _super);
    function WebRadioDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRadioDescriptionMetadata.b = function (a) {
        if (WebRadioDescriptionMetadata.a == null) {
            WebRadioDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRadioDescriptionMetadata.c(WebRadioDescriptionMetadata.a);
        }
        if (a.k(WebRadioDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebRadioDescriptionMetadata.a);
        WebRadioChangeEventArgsDescriptionMetadata.d(a);
        VoidEventArgsDescriptionMetadata.d(a);
    };
    WebRadioDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Radio");
        a.item("__tagNameWC", "String:igc-radio");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Value", "String");
        a.item("Checked", "Boolean");
        a.item("LabelPosition", "ExportedType:string:RadioLabelPosition");
        a.item("LabelPosition@stringUnion", "WebComponents;React");
        a.item("LabelPosition@names", "Before;After");
        a.item("Disabled", "Boolean");
        a.item("Required", "Boolean");
        a.item("Name", "String");
        a.item("Invalid", "Boolean");
        a.item("ChangeRef", "EventRef::change");
        a.item("FocusRef", "EventRef::focus");
        a.item("BlurRef", "EventRef::blur");
    };
    WebRadioDescriptionMetadata.d = function (a) {
        WebRadioDescriptionMetadata.b(a);
        a.ae("WebRadio", function () { return new WebRadioDescription(); });
        a.ad("WebRadio", WebRadioDescriptionMetadata.a);
    };
    WebRadioDescriptionMetadata.$t = markType(WebRadioDescriptionMetadata, 'WebRadioDescriptionMetadata');
    WebRadioDescriptionMetadata.a = null;
    return WebRadioDescriptionMetadata;
}(Base));
export { WebRadioDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebRadioDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRadioChangeEventArgsDescriptionMetadata } from "./WebRadioChangeEventArgsDescriptionMetadata";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
import { WebRadioDescription } from "./WebRadioDescription";
/**
 * @hidden
 */
var WebRadioDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebRadioDescriptionMetadata, _super);
    function WebRadioDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRadioDescriptionMetadata.b = function (a) {
        if (WebRadioDescriptionMetadata.a == null) {
            WebRadioDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRadioDescriptionMetadata.c(WebRadioDescriptionMetadata.a);
        }
        if (a.k(WebRadioDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebRadioDescriptionMetadata.a);
        WebRadioChangeEventArgsDescriptionMetadata.d(a);
        VoidEventArgsDescriptionMetadata.d(a);
    };
    WebRadioDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Radio");
        a.item("__tagNameWC", "String:igc-radio");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Value", "String");
        a.item("Checked", "Boolean");
        a.item("LabelPosition", "ExportedType:string:RadioLabelPosition");
        a.item("LabelPosition@stringUnion", "WebComponents;React");
        a.item("LabelPosition@names", "Before;After");
        a.item("Disabled", "Boolean");
        a.item("Required", "Boolean");
        a.item("Name", "String");
        a.item("Invalid", "Boolean");
        a.item("ChangeRef", "EventRef::change");
        a.item("FocusRef", "EventRef::focus:skipWCPrefix");
        a.item("BlurRef", "EventRef::blur:skipWCPrefix");
    };
    WebRadioDescriptionMetadata.d = function (a) {
        WebRadioDescriptionMetadata.b(a);
        a.ae("WebRadio", function () { return new WebRadioDescription(); });
        a.ad("WebRadio", WebRadioDescriptionMetadata.a);
    };
    WebRadioDescriptionMetadata.$t = markType(WebRadioDescriptionMetadata, 'WebRadioDescriptionMetadata');
    WebRadioDescriptionMetadata.a = null;
    return WebRadioDescriptionMetadata;
}(Base));
export { WebRadioDescriptionMetadata };
